==> haskell-semigroups-0.18.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.3
id: semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
key: semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Semigroup.Generic
abi: 16af22323eddccbd5f8a556232278478
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/semigroups-0.18.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/semigroups-0.18.3
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/semigroups-0.18.3
hs-libraries: HSsemigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semigroups-0.18.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.3
id: semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
key: semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Semigroup.Generic
abi: f833729171d8aeedacf984b736ec248c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/semigroups-0.18.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/semigroups-0.18.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/semigroups-0.18.3
hs-libraries: HSsemigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
